#!/usr/bin/bash
export LANG=en_US.UTF-8
_stage=$1
_stage_lock="/root/initial/tasks/${_stage}.done"
_centos_release=$(/bin/rpm --eval='%centos_ver')

stage1() {
    check_stage
    sed -i "s#ETHDEV.*#ETHDEV $(ip route show default 0.0.0.0/0 | grep -Po '(?<=dev )\S+')#" /etc/wwwacct.conf
    timedatectl set-timezone "${TIME_ZONE}"
    timedatectl set-local-rtc 0
    timedatectl set-ntp true
    service cpanel stop
    mkdir -vp /opt/eig_linux/etc/puppetfeatures
    touch /opt/eig_linux/etc/puppetfeatures/datacycle
    rm -vf {/var/cpanel/globalcache/cpanel.cache,/root/.cpanel/datastore/MOUNTS_CACHE__proc_mounts}
    FACTER_foreman_organization=${BRAND} FACTER_foreman_location=${LOCATION} puppet agent -t --server hensonm.hostgator.com --ca_server hensonca.hostgator.com --tags foreman_registration
    while [ $? -eq 1 ]; do
        sleep 5
         FACTER_foreman_organization=${BRAND} FACTER_foreman_location=${LOCATION} puppet agent -t --server hensonm.hostgator.com --ca_server hensonca.hostgator.com --tags foreman_registration
    done
    puppet agent --disable 'provisioning in progress'
    touch "${_stage_lock}"
}

stage2() {
    check_stage
    puppet agent --enable

    ## applying repos,puppet config
    puppet agent -t --server hensonm.hostgator.com --ca_server hensonca.hostgator.com --tags=yum_repos,puppet_agent,resolvers
    while [ $? -eq 1 ]; do
        sleep 5
         puppet agent -t --server hensonm.hostgator.com --ca_server hensonca.hostgator.com --tags=yum_repos,puppet_agent,resolvers
    done

    ## this will normally fail if prov process failed to configure server in correct hostgroup.
    puppet agent -t --tags=yum_repos,puppet_agent,resolvers
    while [ $? -eq 1 ]; do
        sleep 5
         puppet agent -t --tags=yum_repos,puppet_agent,resolvers
    done

    puppet agent --disable 'provisioning in progress'
    yum clean all -y --enablerepo=*
    yum makecache
    touch "${_stage_lock}"
}

stage3() {
    check_stage
    service ipaliases start
    sed -i '/\(upcp --cron\|optimizefs\|update_db_cache\)/d' /var/spool/cron/root
    if [ "${PRODUCT}" != 'owp' ]; then
      ### Add postgres for BH ESOP-2655
      if [ "${BRAND}" == "BLUEHOST" ]; then
          echo 'y' | /scripts/installpostgres
          /opt/eig_linux/bin-legacy/fixpostgres
      fi
      wget -q -O /root/install_softac.sh --no-check-certificate http://files.softaculous.com/install.sh
      while [ $? -ne 0 ]; do
        sleep 5
        wget -q -O /root/install_softac.sh --no-check-certificate http://files.softaculous.com/install.sh
      done
      chmod 755 /root/install_softac.sh
      /root/install_softac.sh &>> /root/initial/softaculous_install.log
      rm -f /root/install_softac.sh
      touch /opt/eig_linux/etc/puppetfeatures/softaculous
      chmod 4555  /usr/local/cpanel/whostmgr/docroot/cgi/softaculous/bin/soft
    fi

    /usr/local/cpanel/bin/checkallsslcerts
    puppet agent --enable
    puppet agent -t
    while [ $? -ne 0 ]; do
        sleep 5
         puppet agent -t 
    done
    rm -vf /var/cpanel/ssl/*-{CRTINFO,NOT_AFTER,CN,SIGNATURE_CHAIN_VERIFIED,DOMAINS}
    whmapi1 set_autossl_metadata metadata_json='{"clobber_externally_signed":1, "notify_autossl_expiry":0, "notify_autossl_expiry_coverage":0, "notify_autossl_renewal":0, "notify_autossl_renewal_coverage":0, "notify_autossl_renewal_coverage_reduced":0, "notify_autossl_renewal_uncovered_domains":0, "notify_autossl_expiry_coverage_user":0, "notify_autossl_expiry_user":0, "notify_autossl_renewal_coverage_reduced_user":0, "notify_autossl_renewal_coverage_user":0, "notify_autossl_renewal_uncovered_domains_user":0 }'
    /opt/hgmods/multi_shared.pl
    touch /var/cpanel/diya_allow
    rm -vf /admin/MIRRORING.FROM
    yum -y update
    chkconfig fastmail off
    /scripts/fixquotas

    ### custapi randomly drops requests causing it to fail. Adding this as a work around
    /opt/hgmods/hal_accesshash.pl
    while [ $? -eq 1 ]; do
        sleep 5
        /opt/hgmods/hal_accesshash.pl
    done
    sed -i -r '/\/(home[1-9]?)/s/[0-9]$/0/' /etc/fstab
    touch "${_stage_lock}"
}

stage4() {
    check_stage
    #cp_update
    if [ -f /etc/cpanel/ea4/is_ea4 ]; then
        _phpver=ea-php82
        /usr/local/bin/ea_install_profile --install /etc/cpanel/ea4/profiles/custom/ea4_eig_profile.json || exit 1
        _php_vers=( $(/bin/awk -F: '/lsapi/ {print $1}' <(/usr/local/cpanel/bin/rebuild_phpconf --available)) )
        /usr/local/cpanel/bin/rebuild_phpconf --default=${_phpver}$(printf -- ' --%s=lsapi' "${_php_vers[@]}") || exit 1
    fi
    /scripts/upcp --sync
    puppet agent -t
    while [ $? -ne 0 ]; do
        sleep 5
         puppet agent -t
    done
    if ! mysql -BNe 'select User from user where User = "collectd"' -Dmysql | grep -q collectd; then
      _passwd=$(awk '/Password/ {print $2}' /etc/collectd.conf| sed 's/"//g')
      mysql -BNe "CREATE USER 'collectd'@'localhost' IDENTIFIED BY '${_passwd}'; GRANT USAGE, PROCESS, REPLICATION CLIENT ON *.* TO collectd@localhost;"
      echo "${HOSTNAME} added grant"
    fi
    rm -vf /var/cpanel/conf/apache/local
    /scripts/rebuildhttpdconf

    yum -y remove initial-scripts-${BRAND}
    echo "Rebooting in 2 Minutes"
    systemctl --now enable atd
    echo "shutdown -rf now" | at now + 2 min
    touch "${_stage_lock}"
}

check_stage() {
    if [ -f "${_stage_lock}" ]; then
        exit 0
    fi
    echo "Running ${_stage}"
}

${_stage}
